@@ -114,7 +114,7 @@ def get_hubs(en: bool = False, page: str = None) -> list:
     return result
 
 
-def get_post(href: str, session: requests.sessions.Session, full: bool = False) -> dict:
+def get_post(href: str, session: requests.sessions.Session = requests.Session(), full: bool = False) -> dict:
     """ Retusn some information about the post """
     # trying to get the page
     response = session.get(href)
@@ -140,7 +140,7 @@ def get_post(href: str, session: requests.sessions.Session, full: bool = False)
 
     # getting information about post using bs
     result = {
-        'title': post.find('span', class_='post__title-text').text,
+        'title': post.find('h1').text,
         'link': href,
         'hubs': hubs,
         'tags': list(filter(lambda t: not list(filter(lambda h: h['link'] == t['link'], hubs)), tags)),  # hubs also icnlude class post__tag so i need to exclude tags that have the same link as hubs
@@ -154,7 +154,7 @@ def get_post(href: str, session: requests.sessions.Session, full: bool = False)
     return result
 
 
-async def get_post_async(href: str, session: aiohttp.client.ClientSession, full: bool = False):
+async def get_post_async(href: str, session: aiohttp.client.ClientSession = aiohttp.ClientSession(), full: bool = False):
     """ Same as get_post but async """
 
     # trying to get the page
